#
# spec file for package perl-Test-Fatal
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Test-Fatal
Name:           perl-Test-Fatal
Version:        0.017
Release:        1.7
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Incredibly simple helpers for testing code with exceptions
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/R/RJ/RJBS/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(ExtUtils::MakeMaker) >= 6.78
BuildRequires:  perl(Test::More) >= 0.65
BuildRequires:  perl(Try::Tiny) >= 0.07
Requires:       perl(Try::Tiny) >= 0.07
%{perl_requires}

%description
Test::Fatal is an alternative to the popular Test::Exception. It does much
less, but should allow greater flexibility in testing exception-throwing
code with about the same amount of typing.

It exports one routine by default: 'exception'.

*Achtung!* 'exception' intentionally does not manipulate the call stack.
User-written test functions that use 'exception' must be careful to avoid
false positives if exceptions use stack traces that show arguments. For a
more magical approach involving globally overriding 'caller', see
Test::Exception.

%prep
%autosetup  -n %{cpan_name}-%{version}
find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes examples README
%license LICENSE

%changelog
* Tue Jan  3 2023 Tina Müller <timueller+perl@suse.de>
- updated to 0.017
  see /usr/share/doc/packages/perl-Test-Fatal/Changes
  0.017     2022-12-31 16:40:56-05:00 America/New_York
  - update packaging and metadata
* Mon Aug 10 2020 Tina Müller <timueller+perl@suse.de>
- updated to 0.016
  see /usr/share/doc/packages/perl-Test-Fatal/Changes
  0.016     2020-08-08 22:00:14-04:00 America/New_York
  - no changes since trial release of 0.015
  0.015     2018-03-10 17:06:11-05:00 America/New_York (TRIAL RELEASE)
  - add default descriptions to tests
  - work on ancient Test::Builder code
* Tue Apr 14 2015 coolo@suse.com
- updated to 0.014
  see /usr/share/doc/packages/perl-Test-Fatal/Changes
  0.014     2014-12-09 18:35:59-05:00 America/New_York
  - avoid assuming that t/todo.t is always called t/todo.t
* Fri Oct  4 2013 coolo@suse.com
- updated to 0.013
  - rebuild to get a newer compile test that may work on 5.6.x
  - go back to auto-detecting the required Test::More, reverting the
    changes made for [rt.cpan.org #62699]
  - more clearly (and correctly) document the way NOT to use Test::Fatal
    (thanks, Karen Etheridge!)
  - try to fix $TODO not working when the user test uses $T::B::Level
    (thanks, Jesse Luehrs)
* Mon Feb 20 2012 coolo@suse.com
- updated to 0.010
    avoid tickling an overloading bug in perl 5.6 during testing (thanks,
    Zefram)
    advise against using isnt(exception{...},undef)
* Sun Nov 13 2011 lars@linux-schulserver.de
- update to 0.008:
  + revert the mistake by which 0.004 allowed blocks after
    "exception" as well as "success"
* Sat Jun 11 2011 pascal.bleser@opensuse.org
- update to 0.006:
  * crank back the Test::More and Exporter requirements
  * add lives_ok and dies_ok emulation
* Thu Apr 28 2011 pascal.bleser@opensuse.org
- update to 0.005: no user-visible changes
- changes from 0.004:
  * success blocks now allow trailing blocks like finally, catch, etc.
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Thu Nov 11 2010 chris@computersalat.de
- recreated by cpanspec 1.78
- noarch pkg
* Mon Nov  1 2010 pascal.bleser@opensuse.org
- initial package (0.003)
